@@ -47,6 +47,99 @@ static BOOLEAN_ATTRIBUTES: &[&str] = &[
     "visible",
 ];
 
+static EVENT_HANDLER_ATTRIBUTES: &[&str] = &[
+    "onabort",
+    "onauxclick",
+    "onbeforematch",
+    "oncancel",
+    "oncanplay",
+    "oncanplaythrough",
+    "onchange",
+    "onclick",
+    "onclose",
+    "oncontextlost",
+    "oncontextmenu",
+    "oncontextrestored",
+    "oncuechange",
+    "ondblclick",
+    "ondrag",
+    "ondragend",
+    "ondragenter",
+    "ondragleave",
+    "ondragover",
+    "ondragstart",
+    "ondrop",
+    "ondurationchange",
+    "onemptied",
+    "onended",
+    "onformdata",
+    "oninput",
+    "oninvalid",
+    "onkeydown",
+    "onkeypress",
+    "onkeyup",
+    "onloadeddata",
+    "onloadedmetadata",
+    "onloadstart",
+    "onmousedown",
+    "onmouseenter",
+    "onmouseleave",
+    "onmousemove",
+    "onmouseout",
+    "onmouseover",
+    "onmouseup",
+    "onpause",
+    "onplay",
+    "onplaying",
+    "onprogress",
+    "onratechange",
+    "onreset",
+    "onsecuritypolicyviolation",
+    "onseeked",
+    "onseeking",
+    "onselect",
+    "onslotchange",
+    "onstalled",
+    "onsubmit",
+    "onsuspend",
+    "ontimeupdate",
+    "ontoggle",
+    "onvolumechange",
+    "onwaiting",
+    "onwebkitanimationend",
+    "onwebkitanimationiteration",
+    "onwebkitanimationstart",
+    "onwebkittransitionend",
+    "onwheel",
+    "onblur",
+    "onerror",
+    "onfocus",
+    "onload",
+    "onresize",
+    "onscroll",
+    "onafterprint",
+    "onbeforeprint",
+    "onbeforeunload",
+    "onhashchange",
+    "onlanguagechange",
+    "onmessage",
+    "onmessageerror",
+    "onoffline",
+    "ononline",
+    "onpagehide",
+    "onpageshow",
+    "onpopstate",
+    "onrejectionhandled",
+    "onstorage",
+    "onunhandledrejection",
+    "onunload",
+    "oncut",
+    "oncopy",
+    "onpaste",
+    "onreadystatechange",
+    "onvisibilitychange",
+];
+
 // TODO improve list - event handlers + remove multiple whitespace from class +
 // test for custom elements
 static ALLOW_TO_TRIM_ATTRIBUTES: &[&str] = &[
@@ -70,6 +163,10 @@ impl Minifier {
         BOOLEAN_ATTRIBUTES.contains(&name)
     }
 
+    fn is_event_handler_attribute(&self, name: &str) -> bool {
+        EVENT_HANDLER_ATTRIBUTES.contains(&name)
+    }
+
     fn allow_to_trim(&self, name: &str) -> bool {
         ALLOW_TO_TRIM_ATTRIBUTES.contains(&name)
     }
@@ -215,6 +312,22 @@ impl VisitMut for Minifier {
             return;
         }
 
+        let value = n.value.as_ref().unwrap();
+
+        match &n.name {
+            name if self.is_boolean_attribute(name) => {
+                n.value = None;
+            }
+            name if self.is_event_handler_attribute(name)
+                && value.to_lowercase().starts_with("javascript:") =>
+            {
+                let new_value: String = value.as_ref().chars().skip(11).collect();
+
+                n.value = Some(new_value.into());
+            }
+            _ => {}
+        }
+
         if self.is_boolean_attribute(&n.name) {
             n.value = None;
 
